@@ -13,16 +13,21 @@ import requests
 class TestClient(asynctest.TestCase):
     _test_app_id = None
     _test_app_secret = None
+    _one_drive_app_id = None
+    _one_drive_app_secret = None
     _test_tenant_id = None
     resource_data_in_subscription_app_id = None
     resource_data_in_subscription_app_secret = None
     _token = None
     _user_id = None
+    _site_id = None
+    _group_id = None
     _total_users_count = None
     _bulk_size = None
     _notification_url = None
     _valid_message_id = None
     _token_subscription_with_resource_data = None
+    _one_drive_token = None
 
     def setUp(self):
         pass
@@ -35,8 +40,12 @@ class TestClient(asynctest.TestCase):
 
         cls._test_app_id = details["app_id"]
         cls._test_app_secret = details["app_secret"]
+        cls._one_drive_app_id = details["drive_permissions_app_id"]
+        cls._one_drive_app_secret = details["drive_permissions_app_secret"]
         cls._test_tenant_id = details["tenant_id"]
         cls._user_id = details["user_id"]
+        cls._site_id = details["site_id"]
+        cls._group_id = details["group_id"]
         cls._notification_url = details["notification_url"]
         cls._valid_message_id = details["valid_message_id"]
         cls._resource_data_in_subscription_app_id = details["resource_data_in_subscription_app_id"]
@@ -68,6 +77,18 @@ class TestClient(asynctest.TestCase):
         res_json = r.json()
         cls._token_subscription_with_resource_data = res_json['access_token']
 
+        token_params = {
+            'grant_type': 'client_credentials',
+            "scope": "https://graph.microsoft.com/.default",
+            'client_id': cls._one_drive_app_id,
+            'client_secret': cls._one_drive_app_secret,
+        }
+
+        r = requests.post(f"https://login.microsoftonline.com/{cls._test_tenant_id}/oauth2/v2.0/token",
+                          data=token_params)
+        res_json = r.json()
+        cls._one_drive_token = res_json['access_token']
+
     @staticmethod
     def get_instance():
         return GraphAdminClient(enable_logging=True)
@@ -264,7 +285,7 @@ class TestClient(asynctest.TestCase):
 
         q = ODataQuery()
         q.top = 20
-        start = "2021-02-20T00:00:00.000Z"
+        start = "2021-03-01T00:00:00.000Z"
         q.select = ["id", "from", "replyTo", "sentDateTime", "hasAttachments", "receivedDateTime", "subject", "isRead",
                     "parentFolderId", "sender", "toRecipients", "ccRecipients", "bccRecipients", "internetMessageHeaders"]
 
@@ -341,3 +362,75 @@ class TestClient(asynctest.TestCase):
 
         self.assertEqual(status, HTTPStatus.OK)
         self.assertEqual(bytes, type(mail))
+
+    async def test_get_latest_delta_url_user_drive(self):
+        i = self.get_instance()
+
+        delta_url = await i.get_latest_delta_link(USERS, TestClient._user_id, token=TestClient._token)
+
+        self.assertIsNotNone(delta_url)
+
+    async def test_get_latest_delta_url_site_drive(self):
+        i = self.get_instance()
+
+        delta_url = await i.get_latest_delta_link(SITES, TestClient._site_id, token=TestClient._token)
+
+        self.assertIsNotNone(delta_url)
+
+    async def test_get_latest_delta_url_group_drive(self):
+        i = self.get_instance()
+
+        delta_url = await i.get_latest_delta_link(GROUPS, TestClient._group_id, token=TestClient._token)
+
+        self.assertIsNotNone(delta_url)
+
+    async def test_get_drive_file_content(self):
+        i = self.get_instance()
+
+        drive_item_content, status = await i.get_drive_item_content(
+            USERS, TestClient._user_id, "01VYUN2XVST2VSAZWTPVCI4ZBCTSBTMRRW", token=TestClient._one_drive_token)
+
+        self.assertIsNotNone(drive_item_content)
+        self.assertEqual(type(drive_item_content), bytes)
+
+    async def test_list_some_user_drive_content_using_iterator(self):
+        i = self.get_instance()
+
+        delta_url = await i.get_latest_delta_link(USERS, TestClient._user_id, token=TestClient._token)
+
+        items = []
+        async for drive_item in i.list_drive_changes(delta_url, token=TestClient._token):
+            if type(drive_item) == dict:
+                items.append(drive_item)
+
+    async def test_get_sites(self):
+        i = self.get_instance()
+        odata = ODataQuery()
+        odata.top = 10
+        sites = []
+        async for site in i.list_all_sites(
+                token=TestClient._token_subscription_with_resource_data, odata_query=odata):
+            sites.append(site)
+        self.assertIsNotNone(sites)
+
+    async def test_get_sites_bulk(self):
+        i = self.get_instance()
+        odata = ODataQuery()
+        odata.top = 2
+        res, stauts = await i.list_sites_bulk(token=TestClient._token_subscription_with_resource_data, odata_query=odata)
+        self.assertEqual(stauts, HTTPStatus.OK)
+        self.assertEqual(len(res["value"]), 2)
+
+    async def test_get_sites_bulk_and_then_list_more(self):
+        i = self.get_instance()
+        odata = ODataQuery()
+        odata.top = 2
+        res, stauts = await i.list_sites_bulk(token=TestClient._token_subscription_with_resource_data, odata_query=odata)
+        self.assertEqual(stauts, HTTPStatus.OK)
+        self.assertEqual(len(res["value"]), 2)
+
+        res, stauts = await i.list_more_sites(
+            next_url=res[NEXT_KEY], token=TestClient._token_subscription_with_resource_data, odata_query=odata)
+
+        self.assertEqual(stauts, HTTPStatus.OK)
+        self.assertEqual(len(res["value"]), 2)
