@@ -14,10 +14,16 @@ SEARCH = "search"
 USERS = "/users"
 SUBSCRIPTIONS = "/subscriptions"
 MAILS = "/messages"
+GROUPS = "/groups"
+SITES = "/sites"
+DRIVE = "/drive"
 
 # next_key
 NEXT_KEY = "@odata.nextLink"
 
+# delta_key
+DELTA_KEY = "@odata.deltaLink"
+
 
 # Subscription Resources
 class SubscriptionResources(str, Enum):
